Enumeration
SecretError
unstable since: 1
Description [src]
Errors returned by the Secret Service.
None of the errors are appropriate for display to the user. It is up to the application to handle them appropriately.
Stability: Stable
Available since: 1
Members
SECRET_ERROR_PROTOCOL-
Received an invalid data or message from the Secret Service.
- Value:
1 - Nickname:
protocol - Available since: 1
- Value:
SECRET_ERROR_IS_LOCKED-
The item or collection is locked and the operation cannot be performed.
- Value:
2 - Nickname:
is-locked - Available since: 1
- Value:
SECRET_ERROR_NO_SUCH_OBJECT-
No such item or collection found in the Secret Service.
- Value:
3 - Nickname:
no-such-object - Available since: 1
- Value:
SECRET_ERROR_ALREADY_EXISTS-
A relevant item or collection already exists.
- Value:
4 - Nickname:
already-exists - Available since: 1
- Value:
SECRET_ERROR_INVALID_FILE_FORMAT-
The file format is not valid.
- Value:
5 - Nickname:
invalid-file-format - Available since: 1
- Value: